@@ -189,7 +189,7 @@ getPrices <- function(instrument, granularity, count = NULL, from = NULL,
                 if (!is.null(from)) paste0("&from=", from),
                 if (!is.null(to)) paste0("&to=", to))
   resp <- ncurl(url,
-                convert = TRUE,
+                convert = FALSE,
                 follow = TRUE,
                 headers = c(Authorization = paste0("Bearer ", apikey),
                             `Accept-Datetime-Format` = "UNIX",
@@ -1008,7 +1008,7 @@ oanda_positions <- function(instrument, time, server, apikey) {
   url <- paste0("https://api-fx", switch(server, practice = "practice", live = "trade"),
                 ".oanda.com/v3/instruments/", instrument, "/positionBook",
                 if (!missing(time)) paste0("?time=", unclass(as.POSIXct(time))))
-  resp <- ncurl(url, convert = TRUE, follow = TRUE,
+  resp <- ncurl(url, convert = FALSE, follow = TRUE,
                 headers = c(Authorization = paste0("Bearer ", apikey),
                             `Accept-Datetime-Format` = "UNIX", `User-Agent` = .user_agent))
   resp[["status"]] == 200L ||
@@ -1100,7 +1100,7 @@ oanda_orders <- function(instrument, time, server, apikey) {
   url <- paste0("https://api-fx", switch(server, practice = "practice", live = "trade"),
                 ".oanda.com/v3/instruments/", instrument, "/orderBook",
                 if (!missing(time)) paste0("?time=", unclass(as.POSIXct(time))))
-  resp <- ncurl(url, convert = TRUE, follow = TRUE,
+  resp <- ncurl(url, convert = FALSE, follow = TRUE,
                 headers = c(Authorization = paste0("Bearer ", apikey),
                             `Accept-Datetime-Format` = "UNIX", `User-Agent` = .user_agent))
   resp[["status"]] == 200L ||
