@@ -4,9 +4,9 @@ strat <- strat(cloud)
 test_that("autoplot ok", {
   expect_s3_class(autoplot(cloud, ticker = "TKR Co.", theme = "solarized"), "ggplot")
   expect_s3_class(autoplot(strat, subtitle = "Test", theme = "mono"), "ggplot")
-  expect_s3_class(autoplot(cloud, window = "2020-04/", theme = "fresh", type = "s"), "ggplot")
-  expect_s3_class(autoplot(strat, theme = "original", type = "r", custom = "nonexist"), "ggplot")
-  expect_s3_class(autoplot(strat, theme = "conceptual", type = "line", custom = "posn"), "ggplot")
+  expect_s3_class(autoplot(cloud, window = "2020-04/", theme = "okabe-ito", type = "s"), "ggplot")
+  expect_s3_class(autoplot(strat, theme = "classic", type = "r", custom = "nonexist"), "ggplot")
+  expect_s3_class(autoplot(strat, theme = "noguchi", type = "line", custom = "posn"), "ggplot")
   expect_s3_class(autoplot(cloud, type = "bar", custom = "vol"), "ggplot")
   expect_warning(expect_s3_class(autoplot(cloud, type = "line"), "ggplot"), "'custom' not specified")
   expect_warning(expect_s3_class(autoplot(cloud, type = "bar", custom = "vix"), "ggplot"), "does not match")
